@@ -16,6 +16,8 @@ NULL
 
 # todo: write more detail as to what can be found in the intcal.data.frames, allow for draw.contaminate with contam.F14C<1, add smoothing (as in calib.org), solve bug where options are thought to be part of plotting parameters (probably to do with ", ..."), make a table function, prepare calib function with MCMC ccurve
 
+# done: dates close to 0 14C BP now use both prebomb and postbomb curves
+
 # todo: make package 'howmany' (or such), including accumulate (to make sediment records, with e.g. random walk, a function, reading from a file, ...), simulate dating (extrapolation, scatter, outliers, ccurves, offsets; random depths, Andres's code, equal spacing), write Bacon/clam/bchron/oxcal files, cost/benefit plots, proxy simulator
 
 # during package development, the data/intcal.rda file was written as such:
@@ -105,6 +107,7 @@ new.ccdir <- function(cc.dir) {
 #' @param postbomb Use \code{postbomb=TRUE} to get a postbomb calibration curve (default \code{postbomb=FALSE}). For monthly data, type e.g. \code{ccurve("sh1-2_monthly")}
 #' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="ccurves"}.
 #' @param resample The IntCal curves come at a range of 'bin sizes'; every year from 0 to 5 kcal BP, then every 5 yr until 15 kcal BP, then every 10 yr until 25 kcal BP, and every 20 year thereafter. The curves can be resampled to constant bin sizes, e.g. \code{resample=5}. Defaults to FALSE. 
+#' @param glue If a postbomb curve is requested, by default it will be 'glued' to the pre-bomb curve. Set to \code{glue=FALSE} to only return the postbomb curve.
 #' @examples
 #' intcal20 <- ccurve(1)
 #' marine20 <- ccurve(2)
@@ -136,7 +139,7 @@ new.ccdir <- function(cc.dir) {
 #'
 #' Stuiver et al. 1998 INTCAL98 radiocarbon age calibration, 24,000-0 cal BP. Radiocarbon 40, 1041-1083. \doi{10.1017/S0033822200019123}
 #' @export
-ccurve <- function(cc=1, postbomb=FALSE, cc.dir=NULL, resample=0) {
+ccurve <- function(cc=1, postbomb=FALSE, cc.dir=NULL, resample=0, glue=TRUE) {
   if(postbomb) {
     if(cc==1 || tolower(cc) == "nh1")
       fl <- "postbomb_NH1.14C" else
@@ -155,7 +158,10 @@ ccurve <- function(cc=1, postbomb=FALSE, cc.dir=NULL, resample=0) {
                   if(tolower(cc) == "santos")
                     fl <- "Santos.14C" else
                       stop("cannot find this postbomb curve\n", call.=FALSE)
-  } else
+    if(glue)
+      fl.post <- fl
+  }
+  if(glue)
     if(cc==1 || tolower(cc) == "intcal20")
       fl <- "3Col_intcal20.14C" else
       if(cc==2 || tolower(cc) == "marine20")
@@ -211,10 +217,25 @@ ccurve <- function(cc=1, postbomb=FALSE, cc.dir=NULL, resample=0) {
                                                         if(tolower(cc) == "mixed")
                                                           fl <- "mixed.14C" else
                                                           stop("cannot find this curve", call.=FALSE)
-  if(length(cc.dir) == 0)
-    cc <- system.file("extdata/", fl, package='rintcal') else
-      cc <- file.path(cc.dir, fl)  
-  cc <- fastread(cc)
+  if(postbomb && glue) {
+    fl.pre <- fl
+    if(length(cc.dir) == 0) {
+      cc.pre <- system.file("extdata/", fl.pre, package='rintcal')
+      cc.post <- system.file("extdata/", fl.post, package='rintcal')
+    } else {
+      cc.pre <- file.path(cc.dir, fl.pre)
+      cc.post <- file.path(cc.dir, fl.post)
+      }
+    cc.pre <- fastread(cc.pre)
+    cc.post <- fastread(cc.post)
+    cc <- rbind(cc.post, cc.pre)
+    cc <- cc[order(cc[,1]),]
+  } else {
+    if(length(cc.dir) == 0)
+      cc.fl <- system.file("extdata/", fl, package='rintcal') else
+        cc.fl <- file.path(cc.dir, cc.fl)
+    cc <- fastread(cc.fl)
+  }
   if(resample > 0) {
     yr <- seq(min(cc[,1]), max(cc[,1]), by=resample)
     mu <- approx(cc[,1], cc[,2], yr)$y
@@ -282,11 +303,12 @@ mix.ccurves <- function(proportion=.5, cc1="IntCal20", cc2="Marine20", name="mix
 #' @return The custom-made curve (invisibly)
 #' @param prebomb The prebomb curve. Defaults to "IntCal20"
 #' @param postbomb The postbomb curve. Defaults to "NH1" (Hua et al. 2013)
+#' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="ccurves"}.
 #' @examples
 #' my.cc <- glue.ccurves()
 #' @export
-glue.ccurves <- function(prebomb="IntCal20", postbomb="NH1") {
-  glued <- rbind(ccurve(prebomb, FALSE), ccurve(postbomb, TRUE))
+glue.ccurves <- function(prebomb="IntCal20", postbomb="NH1", cc.dir=c()) {
+  glued <- rbind(ccurve(prebomb, FALSE, cc.dir=cc.dir), ccurve(postbomb, TRUE, cc.dir=cc.dir))
   glued <- glued[order(glued[,1]),]
   repeated <- which(diff(glued[,1]) == 0)
   if(length(repeated) > 0)
